| Title: | Develop Concise but Comprehensive Shortened Versions of Psychometric Instruments |
|---|---|
| Description: | Operationalizes the identification problem of which subset of items should be kept in the shortened version of a said psychometric instrument to best represent the set of items comprised in the original version of the said psychometric instrument. |
| Authors: | Loïs Fournier [aut, cre] (ORCID: <https://orcid.org/0000-0001-6743-6456>), Alexandre Heeren [aut] (ORCID: <https://orcid.org/0000-0003-0553-6149>), Stéphanie Baggio [aut] (ORCID: <https://orcid.org/0000-0002-5347-5937>), Luke Clark [aut] (ORCID: <https://orcid.org/0000-0003-1103-2422>), Antonio Verdejo-García [aut] (ORCID: <https://orcid.org/0000-0001-8874-9339>), José C. Perales [aut] (ORCID: <https://orcid.org/0000-0001-5163-8811>), Joël Billieux [aut] (ORCID: <https://orcid.org/0000-0002-7388-6194>) |
| Maintainer: | Loïs Fournier <[email protected]> |
| License: | GPL (>= 3) |
| Version: | 1.0.3 |
| Built: | 2026-05-14 09:22:56 UTC |
| Source: | https://github.com/lfourni2/shortr |
Operationalizes the identification problem of which subset of items should be kept in the shortened version of a said psychometric instrument to best represent the set of items comprised in the original version of the said psychometric instrument.
shortr( n.mat, k, algorithm = base::c("brute.force", "simulated.annealing"), start.temp = 1, cool.fact = 0.999, stop.temp = 0.001, n.runs = 1000, seed = 5107, verbose = TRUE )shortr( n.mat, k, algorithm = base::c("brute.force", "simulated.annealing"), start.temp = 1, cool.fact = 0.999, stop.temp = 0.001, n.runs = 1000, seed = 5107, verbose = TRUE )
n.mat |
The symmetric matrix of associations (e.g., of zero-order polychoric correlation coefficients) computed from the set of items comprised in the original version of the said psychometric instrument. Must be a symmetric matrix of numeric. |
k |
The number of items in the subset of items to be comprised in the shortened version of the said psychometric instrument. Must be a non-null positive integer. |
algorithm |
The combinatorial search algorithm. Must match either |
start.temp |
The starting temperature in the simulated annealing search. Must be a non-null positive numeric lying within the interval (0, 1], and must be greater than stop.temp, the stopping temperature. Default is |
cool.fact |
The cooling factor in the simulated annealing search. Must be a non-null positive numeric lying within the interval (0, 1). Default is |
stop.temp |
The stopping temperature in the simulated annealing search. Must be a non-null positive numeric lying within the interval (0, 1), and must be less than start.temp, the starting temperature. Default is |
n.runs |
The number of runs in the simulated annealing search. Must be a non-null positive integer. Default is |
seed |
The random number generator state for random number generation in the simulated annealing search. Must be a non-null positive integer or must match |
verbose |
Whether information messages should be printed to the console. Must match either |
Let denote the indices corresponding to the set of items comprised in the original version of a said psychometric instrument, and let denote its cardinality, with . Let denote arbitrary indices. Let denote the indices corresponding to the subset of items to be comprised in the shortened version of the said psychometric instrument, and let denote its cardinality, with . Let denote a symmetric matrix of associations (e.g., of zero-order polychoric correlation coefficients) computed from the set of items comprised in the original version of the said psychometric instrument, satisfying for all . Each element represents an association (e.g., a zero-order polychoric correlation coefficient) between the items indexed by and . Let denote the complement of in , with . The objective is to identify the subset of indices of cardinality that maximizes the sum of the absolute values of the associations for all and . Formally, such an identification problem is expressed as follows:
A list of two named objects pertaining to the solution to the identification problem yielded by the combinatorial search algorithm:
A character denoting the subset of items to be comprised in the shortened version of the said psychometric instrument.
A numeric denoting the sum of the absolute values of the associations between the subset of items to be comprised in the shortened version of the said psychometric instrument and the subset of items not to be comprised in the shortened version of the said psychometric instrument.
Fournier, L., Heeren, A., Baggio, S., Clark, L., Verdejo-García, A., Perales, J. C., & Billieux, J. (2026). shortr: Develop concise but comprehensive shortened versions of psychometric instruments (R package version 1.0.3) [Computer software]. doi:10.32614/CRAN.package.shortr
n.mat <- ( stats::runif(n = 25^2, min = -1, max = 1) |> base::matrix(nrow = 25, ncol = 25) |> (\(m) (m + base::t(m)) / 2)() |> (\(m) {base::diag(m) <- 0; m})() ) shortr::shortr( n.mat = n.mat, k = 5, algorithm = "brute.force" )n.mat <- ( stats::runif(n = 25^2, min = -1, max = 1) |> base::matrix(nrow = 25, ncol = 25) |> (\(m) (m + base::t(m)) / 2)() |> (\(m) {base::diag(m) <- 0; m})() ) shortr::shortr( n.mat = n.mat, k = 5, algorithm = "brute.force" )